"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const adrecord_1 = require("../records/adrecord");
const db_1 = require("../utils/db");
const defaultObj = {
    name: 'test3',
    description: 'aaaaaaaa',
    price: 3,
    url: 'http://megak.pl',
    lat: 50.4736473,
    lon: 20.8765745,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('AdRecord returns data from database for one entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield adrecord_1.AdRecord.getOne('abc');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('test');
}));
test('AdRecord returns null from database for nonexistent entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield adrecord_1.AdRecord.getOne('---');
    expect(ad).toBeNull();
}));
test('AdRecord returns data from database for all entries', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield adrecord_1.AdRecord.listAll('');
    expect(ads[0].id).toBeDefined();
    expect(ads).not.toEqual([]);
}));
test('AdRecord returns an array of found entries when searching for letter "e" in the name', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield adrecord_1.AdRecord.listAll('e');
    expect(ads).toBeDefined();
    expect(ads).not.toEqual([]);
}));
test('AdRecord returns an empty array when searching for sth that does not exist', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield adrecord_1.AdRecord.listAll('----------------');
    expect(ads).toEqual([]);
}));
test('AdRecord returns only chosen data', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield adrecord_1.AdRecord.listAll('');
    expect(ads[0].price).toBeUndefined();
}));
test('Inserted AdRecord should have an id', () => __awaiter(void 0, void 0, void 0, function* () {
    const newAd = new adrecord_1.AdRecord(defaultObj);
    yield newAd.insert();
    expect(newAd.id).toBeDefined();
    /*Poniżej sprawdzamy czy nasze id jest poprawnym uuid*/
    expect(newAd.id).toMatch(/^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$/);
}));
test('AdRecord.insert inserts data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const newAd = new adrecord_1.AdRecord(defaultObj);
    yield newAd.insert();
    const foundAd = yield adrecord_1.AdRecord.getOne(newAd.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(newAd.id);
}));
//# sourceMappingURL=ad.test.js.map